"""Top-level package for pc_mouseparty."""

__author__ = """Christopher Marais"""
__email__ = 'padillacoreanolab@gmail.com'
__version__ = '__version__ = '__version__ = '__version__ = '__version__ = '__version__ = '__version__ = '0.0.3'''''''
